# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nifi`](#nifi): Manage Apache NiFi

#### Private Classes

* `nifi::config`: Manage configuration for Apache NiFi
* `nifi::install`: Install Apache NiFi
* `nifi::service`: Manage the Apache NiFi service

### Data types

* [`Nifi::Property`](#nifiproperty)

## Classes

### <a name="nifi"></a>`nifi`

Install, configure and run Apache NiFi

 The hash must be structured like { 'fqdn.example.com' => { 'id' => 1 },... }

#### Examples

##### Defaults

```puppet
include nifi
```

##### Downloading from a different repository

```puppet
class { 'nifi':
  version           => 'x.y.z',
  download_url      => 'https://my.local.repo.example.com/apache/nifi/nifi-x.y.z.tar.gz',
  download_checksum => 'abcde...',
}
```

##### Configuring a NiFi cluster

```puppet
class { 'nifi':
  cluster       => true,
  cluster_nodes => {
    'nifi-1.example.com' => { 'id' => 1 },
    'nifi-2.example.com' => { 'id' => 2 },
    'nifi-3.example.com' => { 'id' => 3 },
  }
}
```

#### Parameters

The following parameters are available in the `nifi` class:

* [`version`](#version)
* [`user`](#user)
* [`group`](#group)
* [`download_url`](#download_url)
* [`download_checksum`](#download_checksum)
* [`download_checksum_type`](#download_checksum_type)
* [`download_tmp_dir`](#download_tmp_dir)
* [`service_limit_nofile`](#service_limit_nofile)
* [`service_limit_nproc`](#service_limit_nproc)
* [`install_root`](#install_root)
* [`var_directory`](#var_directory)
* [`log_directory`](#log_directory)
* [`config_directory`](#config_directory)
* [`nifi_properties`](#nifi_properties)
* [`cluster`](#cluster)
* [`cluster_nodes`](#cluster_nodes)
* [`zookeeper_connect_string`](#zookeeper_connect_string)
* [`zookeeper_client_port`](#zookeeper_client_port)
* [`zookeeper_secure_client_port`](#zookeeper_secure_client_port)
* [`zookeeper_use_secure_client_port`](#zookeeper_use_secure_client_port)
* [`initial_admin_identity`](#initial_admin_identity)

##### <a name="version"></a>`version`

Data type: `String`

The version of Apache NiFi. This must match the version in the
tarball. This is used for managing files, directories and paths in
the service.

Default value: `'1.15.3'`

##### <a name="user"></a>`user`

Data type: `String`

The user owning the nifi installation files, and running the
service.

Default value: `'nifi'`

##### <a name="group"></a>`group`

Data type: `String`

The group owning the nifi installation files, and running the
service.

Default value: `'nifi'`

##### <a name="download_url"></a>`download_url`

Data type: `String`

Where to download the binary installation tarball from.

Default value: `"https://dlcdn.apache.org/nifi/${version}/nifi-${version}-bin.tar.gz"`

##### <a name="download_checksum"></a>`download_checksum`

Data type: `String`

The expected checksum of the downloaded tarball. This is used for
verifying the integrity of the downloaded tarball.

Default value: `'c77fe8e4bc534f16fd5482832285e0bde07495308f31fd6d0fbb3118042daed4'`

##### <a name="download_checksum_type"></a>`download_checksum_type`

Data type: `String`

The checksum type of the downloaded tarball. This is used for
verifying the integrity of the downloaded tarball.

Default value: `'sha256'`

##### <a name="download_tmp_dir"></a>`download_tmp_dir`

Data type: `Stdlib::Absolutepath`

Temporary directory for downloading the tarball.

Default value: `'/var/tmp'`

##### <a name="service_limit_nofile"></a>`service_limit_nofile`

Data type: `Integer`

The limit on number of open files permitted for the service. Used
for LimitNOFILE= in nifi.service.

Default value: `50000`

##### <a name="service_limit_nproc"></a>`service_limit_nproc`

Data type: `Integer`

The limit on number of processes permitted for the service. Used
for LimitNPROC= in nifi.service.

Default value: `10000`

##### <a name="install_root"></a>`install_root`

Data type: `Stdlib::Absolutepath`

The root directory of the nifi installation.

Default value: `'/opt/nifi'`

##### <a name="var_directory"></a>`var_directory`

Data type: `Stdlib::Absolutepath`

The root of the writable paths used by NiFi. Nifi will create
directories beneath this path.  This will implicitly add nifi
properties for working directories and repositories.

Default value: `'/var/opt/nifi'`

##### <a name="log_directory"></a>`log_directory`

Data type: `Stdlib::Absolutepath`

The directory where NiFi stores its user, app and bootstrap logs. Nifi will
create log files beneath this path and take care of log rotation and
deletion.

Default value: `'/var/log/nifi'`

##### <a name="config_directory"></a>`config_directory`

Data type: `Stdlib::Absolutepath`

Directory for NiFi version independent configuration files to be kept
across NiFi version upgrades. NiFi will also write generated configuration
files to this directory. This is used in addition to the "./conf"
directory within each NiFi installation.

Default value: `'/opt/nifi/config'`

##### <a name="nifi_properties"></a>`nifi_properties`

Data type: `Hash[String,Nifi::Property]`

Hash of parameter key/values to be added to conf/nifi.properties.

Default value: `{}`

##### <a name="cluster"></a>`cluster`

Data type: `Boolean`

If true, enables the built-in zookeeper cluster for shared configuration
and state management. The cluster_nodes parameter is used to configure the
zookeeper cluster, and nifi will connect to their local zookeper instance.

Default value: ``false``

##### <a name="cluster_nodes"></a>`cluster_nodes`

Data type: `Hash[
    Stdlib::Fqdn, Struct[{id => Integer[1,255]}]
  ]`

A hash of zookeeper cluster nodes and their ID. The ID must be an integer
between 1 and 255, unique in the cluster, and must not be changed once set.

Default value: `{}`

##### <a name="zookeeper_connect_string"></a>`zookeeper_connect_string`

Data type: `Optional[String]`

The zookeeper connect string is autogenerated from the `cluster_nodes` as
well as the zookeeper client port parameteres. To override this, set the
connecct string using this parameter.

Default value: ``undef``

##### <a name="zookeeper_client_port"></a>`zookeeper_client_port`

Data type: `Stdlib::Port::Unprivileged`

When clustering Nifi, this port is used by NiFi clustering and state
management. This is used for unencrypted communication between NiFi
zookeeper client and the embedded zookeeper server.

Depending on the module parameter `zookeeper_use_secure_client_port`,
NiFi will use either this port or the port controlled by the parameter
`zookeeper_secure_client_port`.

Default value: `2181`

##### <a name="zookeeper_secure_client_port"></a>`zookeeper_secure_client_port`

Data type: `Stdlib::Port::Unprivileged`

When clustering Nifi, this port is used by NiFi clustering and state
management. This is used for encrypted communication between NiFi
zookeeper client and the embedded zookeeper server.

Depending on the module parameter `zookeeper_use_secure_client_port`,
NiFi will use either this port or the port controlled by the parameter
`zookeeper_client_port`.

Default value: `2281`

##### <a name="zookeeper_use_secure_client_port"></a>`zookeeper_use_secure_client_port`

Data type: `Boolean`

Controls if the NiFi cluster will use TLS to connnect to the embedded zookeeper.
If true, NiFi will use TLS and connect to the `zookeeper_secure_client_port`.
If false, NiFi will use cleartext communication to connect to zookeeper on the
`zookeeper_client_port`.

Default value: ``true``

##### <a name="initial_admin_identity"></a>`initial_admin_identity`

Data type: `Optional[String]`



Default value: ``undef``

## Data types

### <a name="nifiproperty"></a>`Nifi::Property`

The Nifi::Property data type.

Alias of

```puppet
Variant[Boolean, Integer, String, Sensitive[String]]
```

